@@ -2,7 +2,7 @@ import ctypes
 import platform
 from typing import Optional, NoReturn
 
-from .error import OnlyWindows
+from .error import PlatformError
 
 
 def enable_ansi() -> Optional[NoReturn]:
@@ -13,7 +13,7 @@ def enable_ansi() -> Optional[NoReturn]:
     """
 
     if platform.system() != "Windows":
-        raise OnlyWindows("This function is for windows only")
+        raise PlatformError("This function is for windows only")
 
     kernel32 = ctypes.windll.kernel32
     kernel32.SetConsoleMode(kernel32.GetStdHandle(-11), 7)
